import React, { useState } from "react";
import PropTypes from "prop-types";
import Machine from "./Machine";
import * as api from "../api";
import { useToast } from "../../../hooks";
import { PowerSettingsNew, LastPage } from "@material-ui/icons";

const MachineContainer = ({ machine }) => {
  const [logs, setLogs] = useState([]);
  const { success, error } = useToast();

  const addLog = text => {
    setLogs(prev => [...prev, text]);
  };

  const wakeMachine = machine => async () => {
    const result = await api.wakeMachine(machine.macAddress);
    addLog(`Success: ${result.success}. Status: ${result.status}`);
    if (result.success) {
      success(result.status);
    } else {
      error(result.status);
    }
  };

  const pingMachine = machine => async () => {
    const result = await api.pingMachine(
      machine.iPv4Address || machine.machineName
    );
    addLog(`Success: ${result.success}. Status: ${result.status}`);
    if (result.success) {
      success(result.status);
    } else {
      error(result.status);
    }
  };

  const actions = [
    {
      code: "wake",
      effect: wakeMachine,
      icon: PowerSettingsNew,
      tooltip: "Wake"
    },
    {
      code: "ping",
      effect: pingMachine,
      icon: LastPage,
      tooltip: "Ping"
    }
  ];

  return <Machine machine={machine} actions={actions} logs={logs} />;
};

MachineContainer.propTypes = {
  machine: PropTypes.object.isRequired
};

export default MachineContainer;
